require "player-events"
player = {}

function player:init()
	self.walk_spr = love.graphics.newImage("gfx/spr/player_walk.png")
	--192 x 48

	self.spr_anim = {
		up = {
			love.graphics.newQuad( 0,   0, 48, 48, 192, 192);
			love.graphics.newQuad(48,   0, 48, 48, 192, 192);
			love.graphics.newQuad(96,   0, 48, 48, 192, 192);
			love.graphics.newQuad(144,  0, 48, 48, 192, 192);
		};
		down = {
			love.graphics.newQuad( 0,   48, 48, 48, 192, 192);
			love.graphics.newQuad(48,   48, 48, 48, 192, 192);
			love.graphics.newQuad(96,   48, 48, 48, 192, 192);
			love.graphics.newQuad(144,  48, 48, 48, 192, 192);
		};
		left = {
			love.graphics.newQuad( 0,   96, 48, 48, 192, 192);
			love.graphics.newQuad(48,   96, 48, 48, 192, 192);
			love.graphics.newQuad(96,   96, 48, 48, 192, 192);
			love.graphics.newQuad(144,  96, 48, 48, 192, 192);
		};
		right = {
			love.graphics.newQuad( 0,   144, 48, 48, 192, 192);
			love.graphics.newQuad(48,   144, 48, 48, 192, 192);
			love.graphics.newQuad(96,   144, 48, 48, 192, 192);
			love.graphics.newQuad(144,  144, 48, 48, 192, 192);
		};
	}

	self.dir = "up"
	self.isMoving = false
	self.anim_spd = 0.0875
	self.anim_timer = 0
	self.anim_iter = 1
	self.anim_max = 4 --frames

	self.x, self.y = 300, screen_h-50
	self.w, self.h = 25, 30
	self.ox, self.oy = self.w/2, self.h/2
	self.speed = 110

	self.chargeTurn = 0
	self.isTakingTurn = false

	self.isRunningEvent = false
	self.msg_counter = 0

	self.level = 1
	self.maxhp = 15
	self.curhp = 15
	self.atk = 1

end

function player:movement(dt)
	--SHORTCUTS
	local k_down = love.keyboard.isDown

	if k_down("up") and not self.isRunningEvent then
		self.isMoving = true
		self.dir = "up"

		local next_y = self.y - self.speed * dt
		if not player:cannot_pass(self.x, next_y) then self.y = next_y end
	end

	if k_down("down") and not self.isRunningEvent then
		self.isMoving = true
		self.dir = "down"

		local next_y = self.y + self.speed * dt
		if not player:cannot_pass(self.x, next_y) then self.y = next_y end
	end

	if k_down("left") and not self.isRunningEvent then
		self.isMoving = true
		self.dir = "left"

		local next_x = self.x - self.speed * dt 
		if not player:cannot_pass(next_x, self.y) then self.x = next_x end
	end

	if k_down("right") and not self.isRunningEvent then
		self.isMoving = true
		self.dir = "right"

		local next_x = self.x + self.speed * dt
		if not player:cannot_pass(next_x, self.y) then self.x = next_x end
	end
end

function player:cannot_pass(x, y)
	for i = 1, #level_handler.bounds do
		if x + self.w >= level_handler.bounds[i][1] and
			x <= level_handler.bounds[i][1] + level_outline.s and
			y + self.h >= level_handler.bounds[i][2] and
			y + self.oy <= level_handler.bounds[i][2] + level_outline.s then
			return true
		end
	end

	return false
end

function player:animation(dt)
	if self.isMoving == true then
		self.anim_timer = self.anim_timer + dt
		if self.anim_timer >= self.anim_spd then
			self.anim_timer = 0
			self.anim_iter = self.anim_iter + 1
			if self.anim_iter > self.anim_max then
				self.anim_iter = 1
			end
		end
	end

	if self.isMoving == false then
		self.anim_timer = 0
		self.anim_iter = 1
	end
end

--------------------------------------------]
---------------  E V E N T S ---------------]
--------------------------------------------]



--------------------------------------------]
--  Draw  --------------------  Draw  ------]
--------------------------------------------]

function player:draw()
	-- DRAW EVENTS --
	event_draw() 

	-- DRAW SPRITES --
	love.graphics.setColor(255,255,255,255)
	love.graphics.drawq(self.walk_spr, self.spr_anim[self.dir][self.anim_iter],
						self.x-12, self.y-12)

	-- DRAW BOUNDING BOXES --

	if level_handler.isDebuggingself == true then

		love.graphics.setColor(255, 50, 50, 100)
		love.graphics.rectangle("fill", self.x, self.y, self.w, self.h)

		love.graphics.setColor(255, 255, 255, 100)
		love.graphics.rectangle("line", self.x, self.y, self.w, self.h)
	end

end


--------------------------------------------]
--  UPDATE  --------------------  UPDATE  --]
--------------------------------------------]

function player:update(dt)
	self:movement(dt)
	self:animation(dt)

	event_updates()
end

function player:keypressed(key)
	if key == "z" then
		run_event = true
		self.msg_counter = self.msg_counter + 1
	end
end


function player:stopped_moving(key)
	if key == "up" and self.isMoving == true then
		self.isMoving = false
		self.anim_iter = 1
		self.dir = "up"

	elseif key == "down" and self.isMoving == true then
		self.isMoving = false
		self.anim_iter = 1
		self.dir = "down"

	elseif key == "left" and self.isMoving == true then
		self.isMoving = false
		self.anim_iter = 1
		self.dir = "left"

	elseif key == "right" and self.isMoving == true then
		self.isMoving = false
		self.anim_iter = 1
		self.dir = "right"

	end

	if not self.isRunningEvent and run_event then
		run_event = false
		self.msg_counter = 0
	end

end